Clazz.declarePackage("J.awtjs");
(function(){
var c$ = Clazz.declareType(J.awtjs, "Event", null);
})();
;//5.0.1-v7 Sat Jan 10 11:40:46 CST 2026
